@@ -39,13 +39,13 @@ class Client(Callbacks, SocketHandler):
         self.account: objects.UserProfile = objects.UserProfile(None)
         self.profile: objects.UserProfile = objects.UserProfile(None)
         self.check_device(self.device_id)
-        
-    def parse_headers(self, data = None):
+        self.headerrs=headers.Headers(deviceId=self.device_id).headers   
+    def parse_headers(self, data = None,deviceId:str=device.device_id):
         if data:
             #print(data)
-            return headers.Headers(data=data, deviceId=self.device_id).headers
+            return headers.Headers(data=data, deviceId=deviceId).headers
         else:
-            return headers.Headers(deviceId=self.device_id).headers
+            return headers.Headers(deviceId=deviceId).headers
         
     def join_voice_chat(self, comId: str, chatId: str, joinType: int = 1):
         """
@@ -205,7 +205,7 @@ class Client(Callbacks, SocketHandler):
 
         response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data), data=data, proxies=self.proxies, verify=self.certificatePath)
         #print(self.parse_headers(data=data))
-        self.run_socket()
+        #self.run_socket()
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
 
         else:
@@ -216,7 +216,7 @@ class Client(Callbacks, SocketHandler):
             self.account: objects.UserProfile = objects.UserProfile(self.json["account"]).UserProfile
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
             headers.sid = self.sid
-            self.start()
+            #self.start()
             return response.status_code
 
     def register(self, nickname: str, email: str, password: str, verificationCode: str, deviceId: str = device.device_id):
@@ -257,8 +257,10 @@ class Client(Callbacks, SocketHandler):
             "identity": email,
             "timestamp": int(timestamp() * 1000)
         })
+        headd=self.parse_headers(deviceId=deviceId,data=data)
+        headd["NDCAUTH"]=None
 
-        response = requests.post(f"{self.api}/g/s/auth/register", data=data, headers=headers.Headers(deviceId=deviceId).headers)
+        response = requests.post(f"{self.api}/g/s/auth/register", data=data, headers=headd)
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
@@ -374,7 +376,7 @@ class Client(Callbacks, SocketHandler):
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
-    def request_verify_code(self, email: str,dev: str,resetPassword: bool = False):
+    def request_verify_code(self, dev: str,email: str, resetPassword: bool = False):
         """
         Request an verification code to the targeted email.
 
@@ -390,7 +392,7 @@ class Client(Callbacks, SocketHandler):
         data = {
             "identity": email,
             "type": 1,
-            "deviceID": device.device_id
+            "deviceID": dev
         }
 
         if resetPassword is True:
@@ -398,7 +400,11 @@ class Client(Callbacks, SocketHandler):
             data["purpose"] = "reset-password"
 
         data = json.dumps(data)
-        response = requests.post(f"{self.api}/g/s/auth/request-security-validation", headers=headers.Headers(deviceId=dev).headers)
+        
+        headd=self.parse_headers(deviceId=dev,data=data)
+        headd["NDCAUTH"]=None
+        response = requests.post(f"{self.api}/g/s/auth/request-security-validation", headers=headd, data=data, proxies=self.proxies, verify=self.certificatePath)
+        #print(self.parse_headers(deviceId=dev,data=data))
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
